@@ -39,7 +39,7 @@ anjuta_shell_placement_get_type (void)
 
 /* enumerations from "anjuta-convert.h" */
 GType
-gedit_convert_error_get_type (void)
+anjuta_convert_error_get_type (void)
 {
   static GType etype = 0;
   if (etype == 0) {
@@ -47,7 +47,7 @@ gedit_convert_error_get_type (void)
       { ANJUTA_CONVERT_ERROR_AUTO_DETECTION_FAILED, "ANJUTA_CONVERT_ERROR_AUTO_DETECTION_FAILED", "failed" },
       { 0, NULL, NULL }
     };
-    etype = g_enum_register_static (g_intern_static_string ("GeditConvertError"), values);
+    etype = g_enum_register_static (g_intern_static_string ("AnjutaConvertError"), values);
   }
   return etype;
 }
@@ -219,6 +219,7 @@ anjuta_vcs_status_get_type (void)
       { ANJUTA_VCS_STATUS_DELETED, "ANJUTA_VCS_STATUS_DELETED", "deleted" },
       { ANJUTA_VCS_STATUS_CONFLICTED, "ANJUTA_VCS_STATUS_CONFLICTED", "conflicted" },
       { ANJUTA_VCS_STATUS_MISSING, "ANJUTA_VCS_STATUS_MISSING", "missing" },
+      { ANJUTA_VCS_STATUS_UNVERSIONED, "ANJUTA_VCS_STATUS_UNVERSIONED", "unversioned" },
       { 0, NULL, NULL }
     };
     etype = g_flags_register_static (g_intern_static_string ("AnjutaVcsStatus"), values);
