@@ -253,14 +253,15 @@ breakpoint_item_new_from_uri (BreakpointsDBase *bd, const gchar* uri, guint line
 {
 	BreakpointItem *bi;
 	
-	g_return_val_if_fail (uri != NULL, NULL);
-
 	bi = breakpoint_item_new (bd);
 	
-	bi->uri = g_strdup (uri);
 	bi->bp.type = IANJUTA_DEBUGGER_BREAKPOINT_ON_LINE | IANJUTA_DEBUGGER_BREAKPOINT_WITH_ENABLE;
-	bi->bp.file = gnome_vfs_get_local_path_from_uri (uri);
-	bi->bp.line = line;
+	if (uri != NULL)
+	{
+		bi->uri = g_strdup (uri);
+		bi->bp.file = gnome_vfs_get_local_path_from_uri (uri);
+		bi->bp.line = line;
+	}
 	bi->bp.enable = enable;
 	
 	return bi;
@@ -318,7 +319,10 @@ breakpoint_item_new_from_string (BreakpointsDBase *bd, const gchar* string, cons
 				bi->bp.type = IANJUTA_DEBUGGER_BREAKPOINT_ON_FUNCTION;
 			}
 			bi->bp.file = g_strndup (string, ptr - string);
-			bi->uri = gnome_vfs_get_uri_from_local_path (bi->bp.file);
+			if (g_path_is_absolute (bi->bp.file))
+			{
+				bi->uri = gnome_vfs_get_uri_from_local_path (bi->bp.file);
+			}
 		}
 	}
 	
@@ -486,12 +490,18 @@ breakpoints_dbase_breakpoint_updated (BreakpointsDBase *bd, BreakpointItem *bi)
 }
 
 static void
-on_editor_saved (IAnjutaEditor *editor, const gchar* uri, BreakpointsDBase *bd)
+on_editor_saved (IAnjutaEditor *editor, GFile* file, BreakpointsDBase *bd)
 {
 	GtkTreeIter iter;
 	GtkTreeModel *model = GTK_TREE_MODEL (bd->model);
+	gchar* uri;
 	
 	g_return_if_fail (model != NULL);
+	
+	if (!file)
+		return;
+	uri = g_file_get_uri (file);
+	
 	/* Update breakpoint position */
 	if (gtk_tree_model_get_iter_first (model, &iter))
 	{
@@ -514,6 +524,7 @@ on_editor_saved (IAnjutaEditor *editor, const gchar* uri, BreakpointsDBase *bd)
 			}	
 		} while (gtk_tree_model_iter_next (model, &iter));
 	}
+	g_free (uri);
 }
 
 static void
@@ -553,14 +564,14 @@ breakpoints_dbase_set_all_in_editor (BreakpointsDBase* bd, IAnjutaEditor* te)
 {
 	GtkTreeModel *model;
 	GtkTreeIter iter;
-	gchar *uri;
+	GFile* file;
 	
 	g_return_if_fail (te != NULL);
 	g_return_if_fail (bd != NULL);
 	g_return_if_fail (bd->treeview != NULL);
 	
-	uri = ianjuta_file_get_uri (IANJUTA_FILE (te), NULL);
-	if (uri == NULL)
+	file = ianjuta_file_get_file (IANJUTA_FILE (te), NULL);
+	if (file == NULL)
 		return;
 	
 	if (!IANJUTA_IS_MARKABLE (te))
@@ -573,13 +584,14 @@ breakpoints_dbase_set_all_in_editor (BreakpointsDBase* bd, IAnjutaEditor* te)
 	
 	if (gtk_tree_model_get_iter_first (model, &iter))
 	{
+		gchar* uri = g_file_get_uri (file);
 		do
 		{
 			BreakpointItem *bi;
 		
 			gtk_tree_model_get (model, &iter, DATA_COLUMN, &bi, -1);
 
-			if ((bi->editor == NULL) && (strcmp (uri, bi->uri) == 0))
+			if ((bi->editor == NULL) && (bi->uri != NULL) && (strcmp (uri, bi->uri) == 0))
 			{
 				bi->editor = te;
 				bi->handle = -1;
@@ -591,8 +603,9 @@ breakpoints_dbase_set_all_in_editor (BreakpointsDBase* bd, IAnjutaEditor* te)
 				breakpoints_dbase_set_in_editor (bd, bi);
 			}
 		} while (gtk_tree_model_iter_next (model, &iter));
+		g_free(uri);
 	}
-	g_free (uri);
+	g_object_unref(file);
 }
 
 static void
@@ -1004,10 +1017,16 @@ breakpoints_dbase_add_breakpoint (BreakpointsDBase *bd,  BreakpointItem *bi)
 	ed = dma_get_current_editor (ANJUTA_PLUGIN(bd->plugin));
 	if ((ed != NULL) && IANJUTA_IS_MARKABLE (ed))
 	{
-		gchar *uri;
+		GFile* file;
+		gchar* uri = NULL;
 		
-		uri = ianjuta_file_get_uri (IANJUTA_FILE (ed), NULL);
-		if ((uri != NULL) && (strcmp (uri, bi->uri) == 0))
+		file = ianjuta_file_get_file (IANJUTA_FILE (ed), NULL);
+		if (file)
+		{
+			uri = g_file_get_uri (file);
+			g_object_unref (file);
+		}
+		if ((uri != NULL) && (bi->uri != NULL) && (strcmp (uri, bi->uri) == 0))
 		{
 			bi->editor = ed;
 			bi->handle = -1;
@@ -1171,7 +1190,7 @@ breakpoints_dbase_find_breakpoint_from_line (BreakpointsDBase *bd, const gchar*
 		
 			gtk_tree_model_get (model, &iter, DATA_COLUMN, &bi, -1);
 			
-			if ((line == bi->bp.line) && (strcmp (uri, bi->uri) == 0)) return bi;
+			if ((line == bi->bp.line) && (bi->uri != NULL) && (strcmp (uri, bi->uri) == 0)) return bi;
 		} while (gtk_tree_model_iter_next (model, &iter));
 	}
 	
@@ -1448,8 +1467,13 @@ breakpoints_dbase_edit_breakpoint (BreakpointsDBase *bd, BreakpointItem *bi)
 		te = dma_get_current_editor (ANJUTA_PLUGIN(bd->plugin));
 		if (te != NULL)
 		{
-			uri = ianjuta_file_get_uri (IANJUTA_FILE (te), NULL);
-			line = ianjuta_editor_get_lineno (te, NULL);
+			GFile* file = ianjuta_file_get_file (IANJUTA_FILE(te), NULL);
+			if (file != NULL)
+			{
+				uri = g_file_get_uri (file);
+				line = ianjuta_editor_get_lineno (te, NULL);
+				g_object_unref (file);
+			}
 		}
 		//NULL uri is ok here
 		bi = breakpoint_item_new_from_uri (bd, uri, line, TRUE);
@@ -1461,23 +1485,20 @@ breakpoints_dbase_edit_breakpoint (BreakpointsDBase *bd, BreakpointItem *bi)
 		gtk_widget_hide (location_entry);
 		gtk_widget_show (location_label);
 	}
-		
-	if (bi->uri != NULL)
+	
+	if (bi->bp.type & IANJUTA_DEBUGGER_BREAKPOINT_ON_LINE)
 	{
-		if (bi->bp.line != 0)
-		{
-			// file and line
-			location = g_strdup_printf ("%s:%d", bi->bp.file, bi->bp.line);
-		}
-		else
-		{
-			// file and function
-			location = g_strdup_printf ("%s:%s", bi->bp.file, bi->bp.function);
-		}
-	}	
-	else if (bi->bp.address != 0)
+		/* file and line */
+		location = g_strdup_printf ("%s:%d", bi->bp.file, bi->bp.line);
+	}
+	else if (bi->bp.type & IANJUTA_DEBUGGER_BREAKPOINT_ON_FUNCTION)
 	{
-		// address
+		/* file and function */
+		location = g_strdup_printf ("%s:%s", bi->bp.file, bi->bp.function);
+	}
+	else if (bi->bp.type & IANJUTA_DEBUGGER_BREAKPOINT_ON_ADDRESS)
+	{
+		/* address */
 		location = g_strdup_printf ("*%lx", bi->bp.address);
 	}
 
@@ -1521,7 +1542,7 @@ breakpoints_dbase_edit_breakpoint (BreakpointsDBase *bd, BreakpointItem *bi)
 				
 				if (*new_location != '\0')
 				{
-					bi = breakpoint_item_new_from_string (bd, new_location, uri);
+					bi = breakpoint_item_new_from_string (bd, new_location, NULL);
 				}
 			}
 		}
@@ -1580,9 +1601,7 @@ on_jump_to_breakpoint_activate (GtkAction * action, BreakpointsDBase *bd)
 	if (valid)
 	{
 		BreakpointItem *bi;
-		
 		gtk_tree_model_get (model, &iter, DATA_COLUMN, &bi, -1);
-
 		g_signal_emit_by_name (bd->plugin, "location-changed", bi->bp.address, bi->uri, bi->bp.line);
 	}
 }
@@ -1592,16 +1611,20 @@ on_toggle_breakpoint_activate (GtkAction * action, BreakpointsDBase *bd)
 {
 	IAnjutaEditor *te;
 	BreakpointItem *bi;
+	GFile* file;
 	gchar *uri;
 	guint line;
 
 	/* Get current editor and line */
 	te = dma_get_current_editor (ANJUTA_PLUGIN (bd->plugin));
 	if (te == NULL) return;       /* Missing editor */
-	uri = ianjuta_file_get_uri (IANJUTA_FILE (te), NULL);
-	if (uri == NULL) return;     /* File not saved yet, it's not possible to put a breakpoint in it */
+	file = ianjuta_file_get_file (IANJUTA_FILE (te), NULL);
+	if (file == NULL) return;     /* File not saved yet, it's not possible to put a breakpoint in it */
 	line = ianjuta_editor_get_lineno (te, NULL);
-
+	
+	uri = g_file_get_uri (file);
+	g_object_unref (file);
+	
 	/* Find corresponding breakpoint
 	 * Try to find right mark (it could have moved) first */
 	bi = breakpoints_dbase_find_breakpoint_from_mark (bd, te, line);
@@ -2006,7 +2029,7 @@ breakpoints_dbase_new (DebugManagerPlugin *plugin)
 	g_signal_connect_swapped (bd->plugin, "debugger-stopped", G_CALLBACK (on_debugger_stopped), bd);
 
 	bd->editor_watch = 
-		anjuta_plugin_add_watch (ANJUTA_PLUGIN(bd->plugin), "document_manager_current_editor",
+		anjuta_plugin_add_watch (ANJUTA_PLUGIN(bd->plugin), IANJUTA_DOCUMENT_MANAGER_CURRENT_DOCUMENT,
 								 on_added_current_editor,
 								 on_removed_current_editor, bd);
 						 
