@@ -6,8 +6,8 @@
 
 G_BEGIN_DECLS
 
-/* VOID:STRING,BOOLEAN,INT,INT (file-view-marshal.list:1) */
-extern void file_view_cclosure_marshal_VOID__STRING_BOOLEAN_INT_INT (GClosure     *closure,
+/* VOID:OBJECT,BOOLEAN,INT,INT (file-view-marshal.list:1) */
+extern void file_view_cclosure_marshal_VOID__OBJECT_BOOLEAN_INT_INT (GClosure     *closure,
                                                                      GValue       *return_value,
                                                                      guint         n_param_values,
                                                                      const GValue *param_values,
