@@ -24,8 +24,6 @@
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-debug.h>
 
-#include <libegg/menu/egg-entry-action.h>
-
 #include "plugin.h"
 #include "search-replace.h"
 #include "search-replace_backend.h"
@@ -61,7 +59,7 @@ static gboolean find_incremental(IAnjutaEditor* te, gchar* expression,
 	se->word_start = FALSE;
 	se->no_limit = FALSE;
 	se->actions_max = 1;
-	se->re = NULL;
+	se->regex_info = NULL;
 
 	info = get_next_match(fb, dir, se);
 	
@@ -205,8 +203,8 @@ static GtkActionEntry actions_search[] = {
 	"<control>h",
 	N_("Search for and replace a string or regular expression with another string"),
     G_CALLBACK (on_find_and_replace1_activate)},
-  { "ActionEditAdvancedSearch", GTK_STOCK_FIND, N_("Advanced Search And Replace"),
-	NULL, N_("New advance search And replace stuff"),
+  { "ActionEditAdvancedSearch", GTK_STOCK_FIND, N_("Search and Replace"),
+	NULL, N_("Search and Replace"),
 	G_CALLBACK (on_find1_activate)},
   { "ActionEditSearchInFiles", NULL, N_("Fin_d in Files..."), NULL,
 	N_("Search for a string in multiple files or directories"),
@@ -269,7 +267,15 @@ dispose (GObject *obj)
 {
 	//SearchPlugin *plugin = ANJUTA_PLUGIN_SEARCH (obj);
 	
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (obj));
+	G_OBJECT_CLASS (parent_class)->dispose (obj);
+}
+
+static void
+finalize (GObject *obj)
+{
+	//SearchPlugin *plugin = ANJUTA_PLUGIN_SEARCH (obj);
+	
+	G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
 static void
@@ -288,6 +294,7 @@ search_plugin_class_init (GObjectClass *klass)
 	plugin_class->activate = activate_plugin;
 	plugin_class->deactivate = deactivate_plugin;
 	klass->dispose = dispose;
+	klass->finalize = finalize;
 }
 ANJUTA_PLUGIN_BEGIN (SearchPlugin, search_plugin);
 ANJUTA_PLUGIN_END;
