@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
 /*
  * plugin.h
- * Copyright (C) Massimo Cora' 2007 <maxcvs@email.it>
+ * Copyright (C) Massimo Cora' 2007-2008 <maxcvs@email.it>
  * 
  * plugin.h is free software.
  * 
@@ -26,9 +26,11 @@
 #define _SYMBOL_DB_H_
 
 #include <libanjuta/anjuta-plugin.h>
+#include <libanjuta/anjuta-launcher.h>
 #include "symbol-db-engine.h"
 #include "symbol-db-engine-iterator.h"
 
+
 G_BEGIN_DECLS
 
 extern GType symbol_db_get_type (GTypeModule *module);
@@ -43,6 +45,13 @@ extern GType symbol_db_get_type (GTypeModule *module);
 typedef struct _SymbolDBPlugin SymbolDBPlugin;
 typedef struct _SymbolDBPluginClass SymbolDBPluginClass;
 
+
+#include "symbol-db-system.h"
+#include "symbol-db-prefs.h"
+
+/* a sort of 'default' value for ctags executable. User must have it installed */
+#define CTAGS_PATH			"/usr/bin/ctags"
+
 struct _SymbolDBPlugin{
 	AnjutaPlugin parent;
 	AnjutaUI *ui;
@@ -52,43 +61,73 @@ struct _SymbolDBPlugin{
 	guint root_watch_id;
 	 
 	/* editor monitor */
+	guint buf_update_timeout_id;
+	gboolean need_symbols_update;
+	GTimer *update_timer;
 	guint editor_watch_id;
 	gchar *project_root_uri;
 	gchar *project_root_dir;
+	gchar *project_opened;
 	
-	/* Symbol's engine connection to database. */
-	SymbolDBEngine *sdbe;
+	/* Symbol's engine connection to database. Instance for local project */
+	SymbolDBEngine *sdbe_project;
 	
-	GtkWidget *dbv_notebook;          	/* symbol main window [gtk_notebook] */	
-	GtkWidget *scrolled_global; 		/* symbol view scrolledwindow for global
-										   symbols */	
+	/* global's one */
+	SymbolDBEngine *sdbe_globals;
+	
+	/* system's population object */
+	SymbolDBSystem *sdbs;
+	
+	/* preferences object */
+	SymbolDBPrefs *sdbp;
+	
+	GtkWidget *dbv_main;					/* symbol main window [gtk_box] */
+	GtkWidget *dbv_notebook;          		/* main notebook */	
+	GtkWidget *scrolled_global; 			/* symbol view scrolledwindow for global
+										   	symbols */
 	GtkWidget *scrolled_locals;
-	GtkWidget *scrolled_search;	
+	GtkWidget *scrolled_search;
+	GtkWidget *progress_bar_project;		/* symbol db progress bar - project */
+	GtkWidget *progress_bar_system;			/* symbol db progress bar - system (globals) */
 	
-	GtkWidget *dbv_view_tree;        	/* symbol_db_view */
+	GtkWidget *dbv_view_tree;        		/* symbol_db_view globals */
 	GtkWidget *dbv_view_tab_label;
 	
-	GtkWidget *dbv_view_tree_locals;	/* local symbols */
+	GtkWidget *dbv_view_tree_locals;		/* local symbols */
 	GtkWidget *dbv_view_locals_tab_label;
 	
-	GtkWidget *dbv_view_tree_search;	/* search symbols */
+	GtkWidget *dbv_view_tree_search;		/* search symbols */
 	GtkWidget *dbv_view_search_tab_label;	
 	
-	GtkWidget *pref_tree_view; 			/* Preferences treeview */
+	GtkWidget *pref_tree_view; 				/* Preferences treeview */
 	
 	/* current editor */
 	GObject *current_editor;
 	GHashTable *editor_connected;	
 	
-	gint files_count;
-	gint files_count_done;
+	/* In session loading? */
+	gboolean session_loading;
+	
+	gint files_count_project;
+	gint files_count_project_done;
+	
+	gint files_count_system;
+	gint files_count_system_done;
+	gchar *current_scanned_package;
+	GList *session_packages;
 };
 
 struct _SymbolDBPluginClass{
 	AnjutaPluginClass parent_class;
+	
+	/* signals */
+	void (* project_import_end) 	();
+	void (* globals_import_end) 	();
+	
 };
 
 
+
 G_END_DECLS
 
 #endif
