@@ -8,8 +8,7 @@
   * the Free Software Foundation; either version 2 of the License, or
   * (at your option) any later version.
   * 
-  * T
-his program is distributed in the hope that it will be useful,
+  * This program is distributed in the hope that it will be useful,
   * but WITHOUT ANY WARRANTY; without even the implied warranty of
   * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   * GNU General Public License for more details.
@@ -30,10 +29,6 @@ his program is distributed in the hope that it will be useful,
 #include <sys/wait.h>
 #include <errno.h>
 
-#include <gnome.h>
-
-#include <libgnomeui/gnome-window-icon.h>
-
 #include <libanjuta/anjuta-utils.h>
 #include <libanjuta/resources.h>
 #include <libanjuta/interfaces/ianjuta-preferences.h>
@@ -85,6 +80,11 @@ on_set_preferences1_activate (GtkAction * action, AnjutaApp *app)
 
 	GtkWidget *preferences_dialog;
 	
+	if (anjuta_preferences_is_dialog_created (app->preferences))
+	{
+		gtk_window_present (GTK_WINDOW (anjuta_preferences_get_dialog (app->preferences)));
+		return;
+	}
 	preferences_dialog = anjuta_preferences_get_dialog (app->preferences);
 	
 	/* Install main application preferences */
@@ -102,36 +102,33 @@ on_set_preferences1_activate (GtkAction * action, AnjutaApp *app)
 }
 
 static void
-help_activate (const gchar *doc_id, const gchar *item)
+help_activate (GtkWindow *parent, const gchar *doc_id, const gchar *item)
 {
-	if (gnome_help_display_with_doc_id (NULL, doc_id, item, NULL, NULL) == FALSE)
-	{
-	  anjuta_util_dialog_error (NULL, _("Unable to display help. Please make sure Anjuta documentation package is install. It can be downloaded from http://anjuta.org"));	
-	}
+	anjuta_util_help_display (parent, doc_id, item);
 }
 
 void
 on_help_manual_activate (GtkAction *action, gpointer data)
 {
-	help_activate ("anjuta-manual", "anjuta-manual.xml");
+	help_activate (data, "anjuta-manual", "anjuta-manual.xml");
 }
 
 void
 on_help_tutorial_activate (GtkAction *action, gpointer data)
 {
-	help_activate ("anjuta-tutorial", "anjuta-tutorial.xml");
+	help_activate (data, "anjuta-tutorial", "anjuta-tutorial.xml");
 }
 
 void
 on_help_advanced_tutorial_activate (GtkAction *action, gpointer data)
 {
-	help_activate ("anjuta-advanced-tutorial", "anjuta-advanced-tutorial.xml");
+	help_activate (data, "anjuta-advanced-tutorial", "anjuta-advanced-tutorial.xml");
 }
 
 void
 on_help_faqs_activate (GtkAction *action, gpointer data)
 {
-	help_activate ("anjuta-faqs", "anjuta-faqs.xml");
+	help_activate (data, "anjuta-faqs", "anjuta-faqs.xml");
 }
 
 void
